# ESQL

ESQL is a way to easily make simple datebases for your discord bot so you don't have to use JSON. 

### how does it work? 

Its pretty simple. you create a datebase, then feed in the variables you want to have.

#### creating a DB

windows:
```esql```

*NIX systems:
```python3 -m esql```